@@ -1020,10 +1020,11 @@ class Builder(Update):
                     else:
                         for fn in package.files:
                             d_path = path.join(builder_path, distrdir)
-                            p_path = path.join(builder_path, pkgdir, fn)
                             try:
-                                shutil.move(p_path, d_path)
-                            except shutil.Error:
+                                for file_name in find(path.join(builder_path, pkgdir)):
+                                    if fn in file_name:
+                                        shutil.move(file_name, d_path)
+                            except (shutil.Error, FileNotFoundError):
                                 pass
                             distdir_files.append(fn)
                     if ef.failed():
